==================
Placement Policies
==================

.. warning::

   JSON formatted policy file is deprecated since Placement 5.0.0 (Wallaby).
   The `oslopolicy-convert-json-to-yaml`__ tool will migrate your existing
   JSON-formatted policy file to YAML in a backward-compatible way.

.. __: https://docs.openstack.org/oslo.policy/latest/cli/oslopolicy-convert-json-to-yaml.html

The following is an overview of all available policies in Placement.
For a sample configuration file, refer to
:doc:`/configuration/sample-policy`.

.. show-policy::
   :config-file: etc/placement/policy-generator.conf
